==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/functions_15.js <==
var searchData=
[
  ['wait_0',['wait',['../classgko_1_1experimental_1_1mpi_1_1request.html#aaddf632d971062a584b0aea23a393381',1,'gko::experimental::mpi::request::wait()'],['../classgko_1_1Timer.html#a895f02685ba5da78e8cceef4246fd399',1,'gko::Timer::wait()'],['../classgko_1_1CpuTimer.html#acf1d0af0c06e29c54b6e4b3b88839a63',1,'gko::CpuTimer::wait()'],['../classgko_1_1CudaTimer.html#a9b555245710892bad0ec3c092255530a',1,'gko::CudaTimer::wait()'],['../classgko_1_1HipTimer.html#a015ae24012216bb2ac53aab461590e08',1,'gko::HipTimer::wait()'],['../classgko_1_1DpcppTimer.html#aea1f314a29fecb8bd45c0ea4a0a17dc9',1,'gko::DpcppTimer::wait()']]],
  ['wait_5fall_1',['wait_all',['../namespacegko_1_1experimental_1_1mpi.html#aff5fd80940add1e4f08a53bfcd131b01',1,'gko::experimental::mpi']]],
  ['what_2',['what',['../classgko_1_1Error.html#aec78ba67d5d7bf123d20afbe086977d0',1,'gko::Error']]],
  ['window_3',['window',['../classgko_1_1experimental_1_1mpi_1_1window.html#a0d8b46cb4e781ef71bccbbfb4a9407fe',1,'gko::experimental::mpi::window::window()'],['../classgko_1_1experimental_1_1mpi_1_1window.html#ae4fca6434fa04ac9b8e9071bfc8cfe70',1,'gko::experimental::mpi::window::window(window &amp;&amp;other)'],['../classgko_1_1experimental_1_1mpi_1_1window.html#aa4604e5b67e90562628e9c3811383195',1,'gko::experimental::mpi::window::window(std::shared_ptr&lt; const Executor &gt; exec, ValueType *base, int num_elems, const communicator &amp;comm, const int disp_unit=sizeof(ValueType), MPI_Info input_info=MPI_INFO_NULL, create_type c_type=create_type::create)']]],
  ['with_5fl_5fsolver_4',['with_l_solver',['../structgko_1_1preconditioner_1_1Ic_1_1parameters__type.html#a27fb2f5820de064959fbf2eefe201549',1,'gko::preconditioner::Ic::parameters_type::with_l_solver()'],['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a0a1d24fbe041045f15ef9385a1784366',1,'gko::preconditioner::Ilu::parameters_type::with_l_solver()']]],
  ['with_5floggers_5',['with_loggers',['../classgko_1_1enable__parameters__type.html#a6ecac33b17246bfea802ebaf23c189b4',1,'gko::enable_parameters_type']]],
  ['with_5fmatrix_5ftype_6',['with_matrix_type',['../namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b',1,'gko']]],
  ['with_5fu_5fsolver_7',['with_u_solver',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a542a9a8066d367167925042d3443c4a2',1,'gko::preconditioner::Ilu::parameters_type']]],
  ['write_8',['write',['../classgko_1_1WritableToMatrixData.html#a96036c3a4bf4c67fa93002808b8b14e2',1,'gko::WritableToMatrixData::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html#a427ff4169c674ce517e93000fffd65b6',1,'gko::log::ProfilerHook::SummaryWriter::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a2f2a866829b190a4866c873fe9f1d4af',1,'gko::log::ProfilerHook::TableSummaryWriter::write()'],['../namespacegko.html#a82d427878e771fc00144d6d2dd4f4e64',1,'gko::write(StreamType &amp;&amp;os, MatrixPtrType &amp;&amp;matrix, layout_type layout=detail::mtx_io_traits&lt; std::remove_cv_t&lt; detail::pointee&lt; MatrixPtrType &gt; &gt; &gt;::default_layout)']]],
  ['write_5fbinary_9',['write_binary',['../namespacegko.html#aba9ca89ef08421197d3dbf84b0ad884c',1,'gko']]],
  ['write_5fbinary_5fraw_10',['write_binary_raw',['../namespacegko.html#a3b27a0c0282115116c160884dc0a9468',1,'gko']]],
  ['write_5fnested_11',['write_nested',['../classgko_1_1log_1_1ProfilerHook_1_1NestedSummaryWriter.html#a3f4bcc48ba9fedd51538adc74e00f3a8',1,'gko::log::ProfilerHook::NestedSummaryWriter::write_nested()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a983a06c472660155ce7edc1cdfbbceda',1,'gko::log::ProfilerHook::TableSummaryWriter::write_nested()']]],
  ['write_5fraw_12',['write_raw',['../namespacegko.html#a2d4b63ce98a16dc2c48aacd534a7b8ba',1,'gko']]]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/functions_15.js <==
var searchData=
[
  ['wait_0',['wait',['../classgko_1_1experimental_1_1mpi_1_1request.html#aaddf632d971062a584b0aea23a393381',1,'gko::experimental::mpi::request::wait()'],['../classgko_1_1Timer.html#a895f02685ba5da78e8cceef4246fd399',1,'gko::Timer::wait()'],['../classgko_1_1CpuTimer.html#acf1d0af0c06e29c54b6e4b3b88839a63',1,'gko::CpuTimer::wait()'],['../classgko_1_1CudaTimer.html#a9b555245710892bad0ec3c092255530a',1,'gko::CudaTimer::wait()'],['../classgko_1_1HipTimer.html#a015ae24012216bb2ac53aab461590e08',1,'gko::HipTimer::wait()'],['../classgko_1_1DpcppTimer.html#aea1f314a29fecb8bd45c0ea4a0a17dc9',1,'gko::DpcppTimer::wait()']]],
  ['wait_5fall_1',['wait_all',['../namespacegko_1_1experimental_1_1mpi.html#aff5fd80940add1e4f08a53bfcd131b01',1,'gko::experimental::mpi']]],
  ['what_2',['what',['../classgko_1_1Error.html#aec78ba67d5d7bf123d20afbe086977d0',1,'gko::Error']]],
  ['window_3',['window',['../classgko_1_1experimental_1_1mpi_1_1window.html#a0d8b46cb4e781ef71bccbbfb4a9407fe',1,'gko::experimental::mpi::window::window()'],['../classgko_1_1experimental_1_1mpi_1_1window.html#ae4fca6434fa04ac9b8e9071bfc8cfe70',1,'gko::experimental::mpi::window::window(window &amp;&amp;other)'],['../classgko_1_1experimental_1_1mpi_1_1window.html#aa4604e5b67e90562628e9c3811383195',1,'gko::experimental::mpi::window::window(std::shared_ptr&lt; const Executor &gt; exec, ValueType *base, int num_elems, const communicator &amp;comm, const int disp_unit=sizeof(ValueType), MPI_Info input_info=MPI_INFO_NULL, create_type c_type=create_type::create)']]],
  ['with_5fl_5fsolver_4',['with_l_solver',['../structgko_1_1preconditioner_1_1Ic_1_1parameters__type.html#a27fb2f5820de064959fbf2eefe201549',1,'gko::preconditioner::Ic::parameters_type::with_l_solver()'],['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a0a1d24fbe041045f15ef9385a1784366',1,'gko::preconditioner::Ilu::parameters_type::with_l_solver()']]],
  ['with_5floggers_5',['with_loggers',['../classgko_1_1enable__parameters__type.html#a6ecac33b17246bfea802ebaf23c189b4',1,'gko::enable_parameters_type']]],
  ['with_5fmatrix_5ftype_6',['with_matrix_type',['../namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b',1,'gko']]],
  ['with_5fu_5fsolver_7',['with_u_solver',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a542a9a8066d367167925042d3443c4a2',1,'gko::preconditioner::Ilu::parameters_type']]],
  ['write_8',['write',['../classgko_1_1WritableToMatrixData.html#a96036c3a4bf4c67fa93002808b8b14e2',1,'gko::WritableToMatrixData::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html#a427ff4169c674ce517e93000fffd65b6',1,'gko::log::ProfilerHook::SummaryWriter::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a2f2a866829b190a4866c873fe9f1d4af',1,'gko::log::ProfilerHook::TableSummaryWriter::write()'],['../namespacegko.html#af82d8f7795fefcf5f38a38895e316c02',1,'gko::write(StreamType &amp;&amp;os, MatrixPtrType &amp;&amp;matrix, layout_type layout=detail::mtx_io_traits&lt; std::remove_cv_t&lt; detail::pointee&lt; MatrixPtrType &gt; &gt; &gt;::default_layout)'],['../namespacegko.html#abc28c235c3fbbf3c495b1850c61746d2',1,'gko::write(std::ostream &amp;os, ptr_param&lt; const LinOp &gt; matrix)']]],
  ['write_5fbinary_9',['write_binary',['../namespacegko.html#aba9ca89ef08421197d3dbf84b0ad884c',1,'gko']]],
  ['write_5fbinary_5fraw_10',['write_binary_raw',['../namespacegko.html#a3b27a0c0282115116c160884dc0a9468',1,'gko']]],
  ['write_5fnested_11',['write_nested',['../classgko_1_1log_1_1ProfilerHook_1_1NestedSummaryWriter.html#a3f4bcc48ba9fedd51538adc74e00f3a8',1,'gko::log::ProfilerHook::NestedSummaryWriter::write_nested()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a983a06c472660155ce7edc1cdfbbceda',1,'gko::log::ProfilerHook::TableSummaryWriter::write_nested()']]],
  ['write_5fraw_12',['write_raw',['../namespacegko.html#a2d4b63ce98a16dc2c48aacd534a7b8ba',1,'gko']]]
];
